import { IIOnBoardingParams, ITokenTypesEnum, IUserAccount, IUserAccountCreateRequest, IUserAccountRemoveRequest, IUserAccountUpdateRequest, IUserAccountWhere, IUserAuth0UpdateFields, IUserProfile, IUserTokenInput, IUserToken, IUsersToken } from '@adminide-stack/core';
import { IBaseService } from '@common-stack/store-mongo';
/**
 * Repository for Accounts, preferbly No Sql
 */
export interface IAccountService<T extends IUserAccount = IUserAccount> extends IBaseService<T> {
    /**
     * Creats a default Account
     */
    createDefaultAccount(user: any, optional?: {
        [key: string]: any;
    }): Promise<IUserAccount>;
    updateUserAccount(user: IUserProfile, userInfo: IUserAuth0UpdateFields): Promise<IUserAccount>;
    /**
     * Creates a new Account
     */
    createAccount(account: IUserAccountCreateRequest): Promise<IUserAccount>;
    /**
     * Find a workspace
     */
    findAccountById(id: string): Promise<IUserAccount | Error>;
    /**
     * Find a workspace
     */
    findAccountByUser(id: string): Promise<IUserAccount | Error>;
    findAccountByEmail(email: string): Promise<IUserAccount | Error>;
    /**
     *  Get list of users who matched the provided criteria
     */
    getUsers(where: IUserAccountWhere): Promise<IUserAccount[]>;
    /**
     * Updates a existing Account
     */
    updateAccount(account: IUserAccountUpdateRequest): Promise<IUserAccount>;
    /**
     * Removes a existing Account
     */
    deleteAccount(account: IUserAccountRemoveRequest): Promise<boolean>;
    accountOnBoarding(input: IIOnBoardingParams, context?: any): Promise<boolean>;
    deleteUserAccount(id: string): Promise<boolean>;
    getUserTokenDetails(userId: string, type: ITokenTypesEnum): Promise<IUserToken>;
    addUserToken(userId: string, token: IUserTokenInput): Promise<boolean>;
    removeUserToken(userId: string, token: IUserTokenInput): Promise<boolean>;
    getAllUserTokens(userIds: string[], tokenType: ITokenTypesEnum[]): Promise<IUsersToken[]>;
    getUserTokens(userId: string, tokenType: ITokenTypesEnum[]): Promise<IUserToken[]>;
    getUserAccountByEmail(email: string): Promise<IUserAccount>;
}
