import { IAccountTeam, IApplicationRoles, IAuthUserInput, IOrganization, IOrganizationCreateRequest, IOrganizationInvitation, IOrganizationInvitationRequest, IOrganizationNotificationValues, IOrganizationRemoveRequest, IOrganizationUpdateRequest, IOrgInvitationMembers, IOrgMembersOutput, IUserContext, IUserProfile } from '@adminide-stack/core';
export interface IOrganizationOnUserJoined {
    team: IAccountTeam;
    organization: IOrganization;
    user: IUserProfile;
    notificationConfig: IOrganizationNotificationValues;
}
export interface IOrganizationOnUserInvitationSend extends IOrganizationInvitationRequest {
    organization: IOrganization;
    team: IAccountTeam;
}
export interface IOrganizationOnUserInvitationResend {
    invitations: IOrganizationInvitation[];
    organization: IOrganization;
    team: IAccountTeam;
    invitedByUser: string;
}
export interface IOrganizationOnMemberRemoved {
    userId: string;
}
export interface IOrganizationService {
    getOrganization(id: string): Promise<IOrganization>;
    getOrganizationByName(name: string): Promise<IOrganization>;
    getOrganizationMembers(orgName: string, offset?: number, limit?: number, criteria?: Record<string, unknown>): Promise<IOrgMembersOutput>;
    getOrgInvitationMembers(orgName: string, offset?: number, limit?: number): Promise<IOrgInvitationMembers>;
    getOrgTeamInvitations(orgName: string, teamId: string): Promise<IOrganizationInvitation[]>;
    createDefaultOrganization(user: IAuthUserInput, userContext?: IUserContext): Promise<IOrganization>;
    getUserOrganizations(userId: string, userContext?: IUserContext): Promise<IOrganization[]>;
    getUserOrganizationsWithRole(userId: string, userContext?: IUserContext): Promise<IOrganization[]>;
    getUserOrgRole(orgName: string, userId: string): Promise<IApplicationRoles>;
    setUserOrgRole(orgName: string, userId: string, role: IApplicationRoles): Promise<boolean>;
    createOrganization(workspace: IOrganizationCreateRequest, userContext?: IUserContext): Promise<IOrganization>;
    updateOrganization(workspace: IOrganizationUpdateRequest, userContext?: IUserContext): Promise<IOrganization>;
    removeOrganization(workspace: IOrganizationRemoveRequest, userContext?: IUserContext): Promise<boolean>;
    /**
     * Remove member of userId from orgMembers
     * @param userId
     * @param userContext
     */
    removeOrgMember(orgName: string, userId: string): Promise<boolean>;
    sendInvitation(request: IOrganizationInvitationRequest): Promise<boolean>;
    declineInvitation(id: string): Promise<boolean>;
    verifyInvitation(id: string): Promise<boolean>;
    acceptInvitation(id: string, user: IUserProfile, notification: IOrganizationNotificationValues): Promise<boolean>;
    resendInvitation(id: string, invitedByUser: string): Promise<boolean>;
    getInvitationById(invitationId: string): Promise<IOrganizationInvitation>;
    notifyUserWhenJoinedOrganization(args: IOrganizationOnUserJoined): Promise<any>;
    notifyOrgMemberBasedOnNotificationConfig(args: IOrganizationOnUserJoined): Promise<any>;
    onUserInvitated(args: IOrganizationOnUserInvitationSend): Promise<any>;
    onUserReinvitated(args: IOrganizationOnUserInvitationResend): Promise<any>;
    updateOrgMemberTeams(userId: string, orgName: string, addToTeams: string[], removeFromTeams: string[]): any;
    removeMemberFromOrganizations(userId: string): Promise<boolean>;
}
